@@ -7,7 +7,7 @@ URL_REPLACEMENTS = {"git@github.com:": "https://github.com/"}
 class RepoApi(object):
     """wrapper class for git.Repo"""
 
-    def __init__(self, repo: git.Repo):
+    def __init__(self, repo: git.Repo) -> None:
         self._repo = repo
 
     def get_current_branch(self) -> str:
@@ -22,5 +22,5 @@ class RepoApi(object):
             if remote_url.startswith(ssh_login):
                 remote_url = remote_url.lstrip(ssh_login)
                 remote_url = URL_REPLACEMENTS[ssh_login] + remote_url
-        remote_url = remote_url.rstrip('.git')
+        remote_url = remote_url.rstrip(".git")
         return remote_url
